@@ -1,12 +1,18 @@
 package Dist::Inkt::Role::WriteREADME;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.007';
+our $VERSION   = '0.008';
 
 use Moose::Role;
 use Pod::Text;
 use namespace::autoclean;
 
+has source_for_readme => (
+	is      => 'ro',
+	lazy    => 1,
+	default => sub { shift->lead_module },
+);
+
 after BUILD => sub {
 	my $self = shift;
 	unshift @{ $self->targets }, 'README';
@@ -28,9 +34,13 @@ sub Build_README
 		utf8     => 1,
 	);
 	
-	my $input = $self->lead_module;
-	$input =~ s{::}{/}g;
-	$input = $self->sourcefile("lib/$input.pm");
+	my $input = $self->source_for_readme;
+	unless ($input =~ /\.(pm|pod)$/)
+	{
+		$input =~ s{::}{/}g;
+		$input = "lib/$input.pm";
+	}
+	$input = $self->sourcefile($input);
 
 	# inherit rights from input pod
 	$self->rights_for_generated_files->{'README'} ||= [
